@@ -29,7 +29,7 @@ from sklearn.metrics import accuracy_score
 from sklearn.metrics import roc_curve, auc
 from sklearn.metrics import precision_recall_curve
 from sklearn.metrics import average_precision_score
-from sklearn.metrics import plot_confusion_matrix
+from sklearn.metrics import confusion_matrix
 
 from imblearn.ensemble import BalancedRandomForestClassifier
 from sklearn.datasets import make_classification
@@ -486,7 +486,8 @@ def get_bar(df,filename,x_name,y_name,figsizex=15,figsizey=15):
     """ Text """
     sns.set(style="whitegrid")
     ax = plt.figure(figsize=(figsizex, figsizey),frameon =False)
-    ax = sns.barplot(df[x_name], df[y_name], palette="GnBu_d")
+    #ax = sns.barplot(df[x_name], df[y_name], palette="GnBu_d")
+    ax = sns.barplot(x=x_name, y=y_name, data=df, palette="GnBu_d")
     plt.show()
     ax.figure.savefig(filename,transparent=False,  bbox_inches='tight',pad_inches=0.05,dpi=300)
     plt.close()
@@ -711,13 +712,13 @@ def nlp_split(note,end_str,start_str):
 # =======================================================
 #
 # =======================================================
-def nlp_cluster(data_df,cluster_column,clusters,prediction_col,max_df_val,min_df_val,max_iter_val,n_init_val,cluster_algo,ngram_range_val):
+def nlp_cluster(data_df,cluster_column,clusters,prediction_col,max_df_val,min_df_val,max_iter_val,n_init_val,ngram_range_val):
     """ Text """
 
     vectorizer = TfidfVectorizer(stop_words='english',use_idf = True, lowercase  = True, max_df = max_df_val, min_df = min_df_val, ngram_range = ngram_range_val)
     X = vectorizer.fit_transform(data_df[cluster_column].values)
 
-    model = KMeans(n_clusters=clusters, init='k-means++', max_iter=max_iter_val, n_init=n_init_val, algorithm='auto',n_jobs = -1,verbose=True)
+    model = KMeans(n_clusters=clusters, init='k-means++', max_iter=max_iter_val, n_init=n_init_val, algorithm='auto',verbose=True)
     model.fit(X)
     labels = model.labels_.tolist()
 
